@@ -39,11 +39,12 @@
 //
 // Main plugin entry point implementation
 //
-#include "npapi.h"
+#include <npapi.h>
+#include <npfunctions.h>
 #include "npupp.h"
 
 #ifndef HIBYTE
-#define HIBYTE(x) ((((uint32)(x)) & 0xff00) >> 8)
+#define HIBYTE(x) ((((uint32_t)(x)) & 0xff00) >> 8)
 #endif
 
 NPNetscapeFuncs NPNFuncs;
