@@ -64,7 +64,7 @@ void NPP_Shutdown(void)
 // will do all the neccessary job
 NPError NPP_New(NPMIMEType pluginType,
                 NPP instance,
-                uint16 mode, int16 argc, char *argn[], char *argv[], NPSavedData * saved)
+                uint16_t mode, int16_t argc, char *argn[], char *argv[], NPSavedData * saved)
 {
     if (instance == NULL)
         return NPERR_INVALID_INSTANCE_ERROR;
@@ -171,7 +171,7 @@ NPError NPP_GetValue(NPP instance, NPPVariable variable, void *value)
 }
 
 NPError NPP_NewStream(NPP instance,
-                      NPMIMEType type, NPStream * stream, NPBool seekable, uint16 * stype)
+                      NPMIMEType type, NPStream * stream, NPBool seekable, uint16_t * stype)
 {
     if (instance == NULL)
         return NPERR_INVALID_INSTANCE_ERROR;
@@ -188,12 +188,12 @@ NPError NPP_NewStream(NPP instance,
     return rv;
 }
 
-int32 NPP_WriteReady(NPP instance, NPStream * stream)
+int32_t NPP_WriteReady(NPP instance, NPStream * stream)
 {
     if (instance == NULL)
         return NPERR_INVALID_INSTANCE_ERROR;
 
-    int32 rv = 0x0fffffff;
+    int32_t rv = 0x0fffffff;
     CPlugin *pPlugin = (CPlugin *) instance->pdata;
 
     if (pPlugin == NULL)
@@ -205,12 +205,12 @@ int32 NPP_WriteReady(NPP instance, NPStream * stream)
     return rv;
 }
 
-int32 NPP_Write(NPP instance, NPStream * stream, int32 offset, int32 len, void *buffer)
+int32_t NPP_Write(NPP instance, NPStream * stream, int32_t offset, int32_t len, void *buffer)
 {
     if (instance == NULL)
         return NPERR_INVALID_INSTANCE_ERROR;
 
-    int32 rv = len;
+    int32_t rv = len;
     CPlugin *pPlugin = (CPlugin *) instance->pdata;
 
     if (pPlugin == NULL)
@@ -271,12 +271,12 @@ NPError NPP_SetValue(NPP instance, NPNVariable variable, void *value)
     return rv;
 }
 
-int16 NPP_HandleEvent(NPP instance, void *event)
+int16_t NPP_HandleEvent(NPP instance, void *event)
 {
     if (instance == NULL)
         return 0;
 
-    int16 rv = 0;
+    int16_t rv = 0;
     CPlugin *pPlugin = (CPlugin *) instance->pdata;
     if (pPlugin)
         rv = pPlugin->handleEvent(event);
