@@ -59,8 +59,6 @@
 
 #include "npruntime.h"
 
-#include "jri.h"
-
 
 /******************************************************************************************
    plug-in function table macros
@@ -86,8 +84,8 @@ typedef void (*NP_LOADDS NPP_ShutdownUPP) (void);
 		(*(FUNC))()
 
 /* NPP_New */
-typedef NPError(*NP_LOADDS NPP_NewUPP) (NPMIMEType pluginType, NPP instance, uint16 mode,
-                                        int16 argc, char *argn[], char *argv[],
+typedef NPError(*NP_LOADDS NPP_NewUPP) (NPMIMEType pluginType, NPP instance, uint16_t mode,
+                                        int16_t argc, char *argn[], char *argv[],
                                         NPSavedData * saved);
 #define NewNPP_NewProc(FUNC)		\
 		((NPP_NewUPP) (FUNC))
@@ -110,7 +108,7 @@ typedef NPError(*NP_LOADDS NPP_SetWindowUPP) (NPP instance, NPWindow * window);
 
 /* NPP_NewStream */
 typedef NPError(*NP_LOADDS NPP_NewStreamUPP) (NPP instance, NPMIMEType type, NPStream * stream,
-                                              NPBool seekable, uint16 * stype);
+                                              NPBool seekable, uint16_t * stype);
 #define NewNPP_NewStreamProc(FUNC)		\
 		((NPP_NewStreamUPP) (FUNC))
 #define CallNPP_NewStreamProc(FUNC, ARG1, ARG2, ARG3, ARG4, ARG5) \
@@ -124,15 +122,15 @@ typedef NPError(*NP_LOADDS NPP_DestroyStreamUPP) (NPP instance, NPStream * strea
 		(*(FUNC))((NPParg), (NPStreamPtr), (NPReasonArg))
 
 /* NPP_WriteReady */
-typedef int32(*NP_LOADDS NPP_WriteReadyUPP) (NPP instance, NPStream * stream);
+typedef int32_t(*NP_LOADDS NPP_WriteReadyUPP) (NPP instance, NPStream * stream);
 #define NewNPP_WriteReadyProc(FUNC)		\
 		((NPP_WriteReadyUPP) (FUNC))
 #define CallNPP_WriteReadyProc(FUNC,  NPParg, NPStreamPtr)		\
 		(*(FUNC))((NPParg), (NPStreamPtr))
 
 /* NPP_Write */
-typedef int32(*NP_LOADDS NPP_WriteUPP) (NPP instance, NPStream * stream, int32 offset, int32 len,
-                                        void *buffer);
+typedef int32_t(*NP_LOADDS NPP_WriteUPP) (NPP instance, NPStream * stream, int32_t offset,
+                                          int32_t len, void *buffer);
 #define NewNPP_WriteProc(FUNC)		\
 		((NPP_WriteUPP) (FUNC))
 #define CallNPP_WriteProc(FUNC,  NPParg, NPStreamPtr, offsetArg, lenArg, bufferPtr)		\
@@ -153,7 +151,7 @@ typedef void (*NP_LOADDS NPP_PrintUPP) (NPP instance, NPPrint * platformPrint);
 		(*(FUNC))((NPParg), (NPPrintArg))
 
 /* NPP_HandleEvent */
-typedef int16(*NP_LOADDS NPP_HandleEventUPP) (NPP instance, void *event);
+typedef int16_t(*NP_LOADDS NPP_HandleEventUPP) (NPP instance, void *event);
 #define NewNPP_HandleEventProc(FUNC)		\
 		((NPP_HandleEventUPP) (FUNC))
 #define CallNPP_HandleEventProc(FUNC,  NPParg, voidPtr)		\
@@ -210,7 +208,7 @@ typedef NPError(*NP_LOADDS NPN_GetURLNotifyUPP) (NPP instance, const char *url,
 
 /* NPN_PostUrlNotify */
 typedef NPError(*NP_LOADDS NPN_PostURLNotifyUPP) (NPP instance, const char *url, const char *window,
-                                                  uint32 len, const char *buf, NPBool file,
+                                                  uint32_t len, const char *buf, NPBool file,
                                                   void *notifyData);
 #define NewNPN_PostURLNotifyProc(FUNC)		\
 		((NPN_PostURLNotifyUPP) (FUNC))
@@ -226,7 +224,7 @@ typedef NPError(*NP_LOADDS NPN_GetURLUPP) (NPP instance, const char *url, const
 
 /* NPN_PostUrl */
 typedef NPError(*NP_LOADDS NPN_PostURLUPP) (NPP instance, const char *url, const char *window,
-                                            uint32 len, const char *buf, NPBool file);
+                                            uint32_t len, const char *buf, NPBool file);
 #define NewNPN_PostURLProc(FUNC)		\
 		((NPN_PostURLUPP) (FUNC))
 #define CallNPN_PostURLProc(FUNC, ARG1, ARG2, ARG3, ARG4, ARG5, ARG6) \
@@ -248,7 +246,8 @@ typedef NPError(*NP_LOADDS NPN_NewStreamUPP) (NPP instance, NPMIMEType type, con
 		(*(FUNC))((npp), (type), (window), (stream))
 
 /* NPN_Write */
-typedef int32(*NP_LOADDS NPN_WriteUPP) (NPP instance, NPStream * stream, int32 len, void *buffer);
+typedef int32_t(*NP_LOADDS NPN_WriteUPP) (NPP instance, NPStream * stream, int32_t len,
+                                          void *buffer);
 #define NewNPN_WriteProc(FUNC)		\
 		((NPN_WriteUPP) (FUNC))
 #define CallNPN_WriteProc(FUNC, npp, stream, len, buffer)		\
@@ -276,7 +275,7 @@ typedef const char *(*NP_LOADDS NPN_UserAgentUPP) (NPP instance);
                 (*(FUNC))((ARG1))
 
 /* NPN_MemAlloc */
-typedef void *(*NP_LOADDS NPN_MemAllocUPP) (uint32 size);
+typedef void *(*NP_LOADDS NPN_MemAllocUPP) (uint32_t size);
 #define NewNPN_MemAllocProc(FUNC)		\
 		((NPN_MemAllocUPP) (FUNC))
 #define CallNPN_MemAllocProc(FUNC, ARG1)		\
@@ -290,7 +289,7 @@ typedef void (*NP_LOADDS NPN_MemFreeUPP) (void *ptr);
 		(*(FUNC))((ARG1))
 
 /* NPN_MemFlush */
-typedef uint32(*NP_LOADDS NPN_MemFlushUPP) (uint32 size);
+typedef uint32_t(*NP_LOADDS NPN_MemFlushUPP) (uint32_t size);
 #define NewNPN_MemFlushProc(FUNC)		\
 		((NPN_MemFlushUPP) (FUNC))
 #define CallNPN_MemFlushProc(FUNC, ARG1)		\
@@ -303,20 +302,6 @@ typedef void (*NP_LOADDS NPN_ReloadPluginsUPP) (NPBool reloadPages);
 #define CallNPN_ReloadPluginsProc(FUNC, ARG1)		\
 		(*(FUNC))((ARG1))
 
-/* NPN_GetJavaEnv */
-typedef JRIEnv *(*NP_LOADDS NPN_GetJavaEnvUPP) (void);
-#define NewNPN_GetJavaEnvProc(FUNC)		\
-		((NPN_GetJavaEnvUPP) (FUNC))
-#define CallNPN_GetJavaEnvProc(FUNC)		\
-		(*(FUNC))()
-
-/* NPN_GetJavaPeer */
-typedef jref(*NP_LOADDS NPN_GetJavaPeerUPP) (NPP instance);
-#define NewNPN_GetJavaPeerProc(FUNC)		\
-		((NPN_GetJavaPeerUPP) (FUNC))
-#define CallNPN_GetJavaPeerProc(FUNC, ARG1)		\
-		(*(FUNC))((ARG1))
-
 /* NPN_InvalidateRect */
 typedef void (*NP_LOADDS NPN_InvalidateRectUPP) (NPP instance, NPRect * rect);
 #define NewNPN_InvalidateRectProc(FUNC)		\
@@ -522,10 +507,10 @@ typedef bool(*NP_LOADDS NPN_ConstructUPP) (NPP npp, NPObject * obj, const NPVari
 /******************************************************************************************
  * The actual plugin function table definitions
  *******************************************************************************************/
-
+#ifdef DISABLE_THIS
 typedef struct _NPPluginFuncs {
-    uint16 size;
-    uint16 version;
+    uint16_t size;
+    uint16_t version;
     NPP_NewUPP newp;
     NPP_DestroyUPP destroy;
     NPP_SetWindowUPP setwindow;
@@ -543,8 +528,8 @@ typedef struct _NPPluginFuncs {
 } NPPluginFuncs;
 
 typedef struct _NPNetscapeFuncs {
-    uint16 size;
-    uint16 version;
+    uint16_t size;
+    uint16_t version;
     NPN_GetURLUPP geturl;
     NPN_PostURLUPP posturl;
     NPN_RequestReadUPP requestread;
@@ -591,7 +576,7 @@ typedef struct _NPNetscapeFuncs {
     // NPN_PluginThreadAsyncCallUPP pluginthreadasynccall;
     // NPN_ConstructUPP construct;
 } NPNetscapeFuncs;
-
+#endif
 
 #ifdef XP_MACOSX
 /******************************************************************************************
@@ -625,11 +610,11 @@ enum {
 };
 
 typedef struct _BPSupportedMIMETypes {
-    SInt32 structVersion;       /* struct version */
+    Sint32_t structVersion;     /* struct version */
     Handle typeStrings;         /* STR# formated handle, allocated by plug-in */
     Handle infoStrings;         /* STR# formated handle, allocated by plug-in */
 } BPSupportedMIMETypes;
-OSErr BP_GetSupportedMIMETypes(BPSupportedMIMETypes * mimeInfo, UInt32 flags);
+OSErr BP_GetSupportedMIMETypes(BPSupportedMIMETypes * mimeInfo, Uint32_t flags);
 
  /* NP_GetMIMEDescription */
 #define NP_GETMIMEDESCRIPTION_NAME "NP_GetMIMEDescription"
@@ -640,7 +625,7 @@ typedef const char *(*NP_LOADDS NP_GetMIMEDescriptionUPP) ();
 		(*(FUNC))()
 
 /* BP_GetSupportedMIMETypes */
-typedef OSErr(*NP_LOADDS BP_GetSupportedMIMETypesUPP) (BPSupportedMIMETypes *, UInt32);
+typedef OSErr(*NP_LOADDS BP_GetSupportedMIMETypesUPP) (BPSupportedMIMETypes *, Uint32_t);
 #define NewBP_GetSupportedMIMETypesEntryProc(FUNC)		\
 		((BP_GetSupportedMIMETypesUPP) (FUNC))
 #define CallBP_GetMIMEDescEntryProc(FUNC,  mimeInfo, flags)		\
