@@ -40,10 +40,11 @@
 #include "plugin_setup.h"
 
 // void new_instance(CPlugin * instance, nsPluginCreateData * parameters)
-void new_instance(CPlugin * instance, int16 argc, char *argn[], char *argv[])
+void new_instance(CPlugin * instance, int16_t argc, char *argn[], char *argv[])
 {
 
-    guint i, j;
+    int16_t i;
+    guint j;
     gint newwindow = 0;
     gint loop = 0;
     gboolean autohref = FALSE;
@@ -59,9 +60,14 @@ void new_instance(CPlugin * instance, int16 argc, char *argn[], char *argv[])
     GError *error;
     NPError nperror;
     guint32 supportsWindowless = FALSE; // NPBool + padding
+    gchar *app_name;
 
     if (instance->mode == NP_EMBED) {
         for (i = 0; i < argc; i++) {
+
+            if (argn[i] == NULL)
+                continue;
+
             printf("ARG: %s = %s\n", argn[i], argv[i]);
 
             if (g_ascii_strcasecmp(argn[i], "name") == 0) {
@@ -103,15 +109,23 @@ void new_instance(CPlugin * instance, int16 argc, char *argn[], char *argv[])
                 sscanf(argv[i], "%i", &height);
             }
 
-            if (g_ascii_strcasecmp(argn[i], "src") == 0) {
+            if (g_ascii_strcasecmp(argn[i], "src") == 0 || g_ascii_strcasecmp(argn[i], "url") == 0) {
                 item = g_new0(ListItem, 1);
-                g_strlcpy(item->src, argv[i], 4096);
+                if (g_strrstr(argv[i], "XXmovies.apple.com")) { // tmp disabled, to reenable remove XX
+                    tmp = g_strrstr(argv[i], "movies.");
+                    if (tmp != NULL && strlen(tmp) > strlen("movies.")) {
+                        tmp = tmp + strlen("movies.");
+                        g_snprintf(item->src, 4096, "http://www.%s", tmp);
+                    } else {
+                        g_strlcpy(item->src, argv[i], 4096);
+                    }
+                } else {
+                    g_strlcpy(item->src, argv[i], 4096);
+                }
                 // printf("Item src = %s\n",item->src);
                 item->streaming = streaming(item->src);
                 item->play = TRUE;
                 item->id = instance->nextid++;
-                //if (g_strrstr(argv[i],"apple.com"))
-                //    setPreference(instance, "general.useragent.override","QuickTime/7.6.2");
                 instance->playlist = g_list_append(instance->playlist, item);
                 src = item;
             }
@@ -129,7 +143,17 @@ void new_instance(CPlugin * instance, int16 argc, char *argn[], char *argv[])
 
             if (g_ascii_strcasecmp(argn[i], "href") == 0) {
                 item = g_new0(ListItem, 1);
-                g_strlcpy(item->src, argv[i], 4096);
+                if (g_strrstr(argv[i], "XXmovies.apple.com")) {
+                    tmp = g_strrstr(argv[i], "movies.");
+                    if (tmp != NULL && strlen(tmp) > strlen("movies.")) {
+                        tmp = tmp + strlen("movies.");
+                        g_snprintf(item->src, 4096, "http://www.%s", tmp);
+                    } else {
+                        g_strlcpy(item->src, argv[i], 4096);
+                    }
+                } else {
+                    g_strlcpy(item->src, argv[i], 4096);
+                }
                 // printf("Item href = %s\n",item->src);
                 item->streaming = streaming(item->src);
                 item->play = FALSE;
@@ -169,7 +193,18 @@ void new_instance(CPlugin * instance, int16 argc, char *argn[], char *argv[])
             if (g_ascii_strcasecmp(argn[i], "target") == 0) {
                 if (g_ascii_strcasecmp(argv[i], "quicktimeplayer") == 0) {
                     newwindow = TRUE;
+                } else {
+                    item = g_new0(ListItem, 1);
+                    g_strlcpy(item->src, argv[i], 4096);
+                    // printf("Item href = %s\n",item->src);
+                    item->streaming = streaming(item->src);
+                    item->play = FALSE;
+                    item->id = instance->nextid++;
+                    instance->playlist = g_list_append(instance->playlist, item);
+                    src = item;
+                    instance->show_controls = 0;
                 }
+
             }
 
             if (g_ascii_strcasecmp(argn[i], "hidden") == 0) {
@@ -205,6 +240,7 @@ void new_instance(CPlugin * instance, int16 argc, char *argn[], char *argv[])
             if (g_ascii_strcasecmp(argn[i], "autohref") == 0) {
                 if (strstr(argv[i], "true")
                     || strstr(argv[i], "yes")
+                    || strstr(argv[i], "autohref")
                     || strstr(argv[i], "1")) {
                     autohref = TRUE;
                 } else {
@@ -212,6 +248,10 @@ void new_instance(CPlugin * instance, int16 argc, char *argn[], char *argv[])
                 }
             }
 
+            if (g_ascii_strcasecmp(argn[i], "data") == 0) {
+                // autohref = TRUE;
+            }
+
             if ((g_ascii_strcasecmp(argn[i], "autoplay") == 0)
                 || (g_ascii_strcasecmp(argn[i], "autostart") == 0)) {
                 if (g_ascii_strcasecmp(argv[i], "false") == 0
@@ -344,6 +384,7 @@ void new_instance(CPlugin * instance, int16 argc, char *argn[], char *argv[])
                     || g_ascii_strcasecmp(argv[i], "yes") == 0
                     || g_ascii_strcasecmp(argv[i], "1") == 0) {
                     instance->debug = TRUE;
+
                 } else {
                     instance->debug = FALSE;
                 }
@@ -359,14 +400,34 @@ void new_instance(CPlugin * instance, int16 argc, char *argn[], char *argv[])
                 }
             }
 
+            if (g_ascii_strncasecmp(argn[i], "qtnext", 6) == 0) {
+                parse = g_strsplit_set(argv[i], "<>", 0);
+                if (parse[1] != NULL) {
+                    item = g_new0(ListItem, 1);
+                    tmp = g_strrstr(src->src, "/");
+                    if (tmp) {
+                        g_strlcpy(item->src, src->src, 1024);
+                        tmp = g_strrstr(item->src, "/");
+                        tmp[1] = '\0';
+                        g_strlcat(item->src, parse[1], 4096);
+                    } else {
+                        g_strlcpy(item->src, parse[1], 4096);
+                    }
+                    item->streaming = streaming(item->src);
+                    item->play = TRUE;
+                    item->id = instance->nextid++;
+                    instance->playlist = g_list_append(instance->playlist, item);
+                }
+                g_strfreev(parse);
+            }
+
         };
     } else {
 
     }
 
-    nperror =
-        NPN_GetValue(instance->mInstance, (NPNVariable) 17 /* NPNVSupportsWindowless */ ,
-                     &supportsWindowless);
+    nperror = NPN_GetValue(instance->mInstance, (NPNVariable) 17 /* NPNVSupportsWindowless */ ,
+                           &supportsWindowless);
     supportsWindowless = (nperror == NPERR_NO_ERROR) && supportsWindowless;
     if (instance->windowless) {
         if (supportsWindowless) {
@@ -430,15 +491,25 @@ void new_instance(CPlugin * instance, int16 argc, char *argn[], char *argv[])
         // generate a random controlid
         rand = g_rand_new();
         href->controlid = g_rand_int_range(rand, 0, 65535);
+        // printf("autohref controlid = %i\n", href->controlid);
         g_rand_free(rand);
-        tmp = g_strdup_printf("/control/%i", item->controlid);
+        tmp = g_strdup_printf("/control/%i", href->controlid);
         g_strlcpy(href->path, tmp, 1024);
         g_free(tmp);
 
         //list_dump(instance->playlist);
+        app_name = NULL;
+        if (instance->player_backend != NULL) {
+            app_name = g_find_program_in_path(instance->player_backend);
+        }
+        if (app_name == NULL) {
+            app_name = g_find_program_in_path("gnome-mplayer");
+            if (app_name == NULL)
+                app_name = g_find_program_in_path("gnome-mplayer-minimal");
+        }
 
-        arg[i++] = g_strdup("gnome-mplayer");
-        arg[i++] = g_strdup_printf("--controlid=%i", item->controlid);
+        arg[i++] = g_strdup(app_name);
+        arg[i++] = g_strdup_printf("--controlid=%i", href->controlid);
         arg[i] = NULL;
         error = NULL;
         if (g_spawn_async(NULL, arg, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, NULL, &error) == FALSE) {
@@ -447,6 +518,7 @@ void new_instance(CPlugin * instance, int16 argc, char *argn[], char *argv[])
             error = NULL;
         }
         NPN_GetURLNotify(instance->mInstance, href->src, NULL, href);
+        g_free(app_name);
     }
 
 
@@ -475,6 +547,9 @@ gint streaming(gchar * url)
     if (g_ascii_strncasecmp(url, "dvd://", 6) == 0)
         ret = 1;
 
+    if (g_strrstr(url, ".m3u") != NULL)
+        ret = 1;
+
     if (g_ascii_strncasecmp(url, "file://", 7) == 0) {
         p = g_filename_from_uri(url, NULL, NULL);
         if (p != NULL) {
