@@ -41,7 +41,7 @@
 #include "plugin_dbus.h"
 
 // void new_instance(CPlugin * instance, nsPluginCreateData * parameters);
-void new_instance(CPlugin * instance, int16 argc, char *argn[], char *argv[]);
+void new_instance(CPlugin * instance, int16_t argc, char *argn[], char *argv[]);
 gint streaming(gchar * url);
 
 #endif                          // _PLUGIN_SETUP_H
